/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasFieldFromDiskFrameDescriptor.java 20828 2011-02-03 10:12:20Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guibuilder;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.io.File;

import javax.swing.JFileChooser;

import org.ow2.jonas.autostart.builder.Builder;
import org.ow2.jonas.autostart.configurationframe.ConfiguratorFrameDescriptor;
import org.ow2.jonas.autostart.frame.BuildSummaryFrame;
import org.ow2.jonas.autostart.frame.GettingJonasFieldFromDiskFrame;
import org.ow2.jonas.autostart.fullwizard.FullWizardPanelDescriptor;
import org.ow2.jonas.autostart.utility.Utility;

/**
 * This class instanciates GettingJonasFieldFromDiskFrame.
 * @author skabore
 */
public class GettingJonasFieldFromDiskFrameDescriptor extends FullWizardPanelDescriptor implements ActionListener, KeyListener {

    /**
     * The identifier.
     */
    public static final String IDENTIFIER = "GETTING_JONAS_FIELD_FROM_DISK_PANEL";

    /**
     * the gettingJonasFieldFromDiskFrame.
     */
    private GettingJonasFieldFromDiskFrame gettingJonasFieldFrame;

    /**
     * The builder librairy.
     */
    private Builder builder;

    /**
     * The constructeur.
     * @param builder the builder librairy
     * @param steps, the required steps to create a starter
     */
    public GettingJonasFieldFromDiskFrameDescriptor(final Builder builder, final int steps) {
        this.builder = builder;
        this.gettingJonasFieldFrame = new GettingJonasFieldFromDiskFrame(steps);
        this.gettingJonasFieldFrame.addActionListener(this);
        this.gettingJonasFieldFrame.addKeyListener(this);
        setPanelDescriptorIdentifier(IDENTIFIER);
        setPanelComponent(this.gettingJonasFieldFrame);
    }

    /**
     * @return builder.
     */
    public Builder getBuilder() {
        return this.builder;
    }

    /**
     * @return the next panel identifier.
     */
    @Override
    public Object getNextPanelDescriptor() {
        getWizard().getConfigButton().setVisible(true);
        getWizard().setCurrentFrame(1);
        String[] applicationListItems = {};
        if (this.builder.getApplicationLocation() != null && this.builder.getApplicationLocation().length > 0) {
            applicationListItems = this.builder.getApplicationLocation();
        }
        BuildSummaryFrame.getApplicationList().setListData(applicationListItems);
        return BuildSummaryFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return the back panel identifier.
     */
    @Override
    public Object getBackPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        return GettingJonasOptionFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return the config panel identifier.
     */
    @Override
    public Object getConfigPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        getWizard().setCurrentFrame(1);
        return ConfiguratorFrameDescriptor.IDENTIFIER;
    }

    /**
     * Check if the next button must be enabled.
     */
    @Override
    public void aboutToDisplayPanel() {
        setNextButtonAccordingToJonasRootField();
    }

    /**
     * Set the next button enabled according fields values.
     */
    private void setNextButtonAccordingToJonasRootField() {
        if (Utility.isValidJOnASRootFolder(new File(this.gettingJonasFieldFrame.getJonasRoot().getText()))) {
            getWizard().setNextFinishButtonEnabled(true);
            getWizard().getConfigButton().setVisible(true);
            this.gettingJonasFieldFrame.getErrorLabel().setText("");
            if (this.gettingJonasFieldFrame.getUseJonasBase().isSelected()) {
                disabledConfigButtonAccordingToJonasBaseField();
            }
            File jRoot = new File(this.gettingJonasFieldFrame.getJonasRoot().getText());
            this.builder.setJonasRoot(jRoot);
        } else {
            if (!this.gettingJonasFieldFrame.getJonasRoot().getText().equals("")) {
                this.gettingJonasFieldFrame.getErrorLabel().setText("Error :" + " JOnAS Root folder is not valid.");
            }
            getWizard().setNextFinishButtonEnabled(false);
            getWizard().getConfigButton().setVisible(false);
        }
    }

    /**
     * Disable config button according JOnAS Base fields.
     */
    private void disabledConfigButtonAccordingToJonasBaseField() {
        if (Utility.isValidJOnASBaseFolder(new File(this.gettingJonasFieldFrame.getJonasBase().getText()))
                && this.gettingJonasFieldFrame.getUseJonasBase().isSelected()) {
            getWizard().getConfigButton().setVisible(false);
            this.gettingJonasFieldFrame.getErrorLabel().setText("");
            File jBase = new File(this.gettingJonasFieldFrame.getJonasBase().getText());
            this.builder.setJonasBase(jBase);
        } else {
            if (Utility.isValidJOnASRootFolder(new File(this.gettingJonasFieldFrame.getJonasRoot().getText()))) {
                getWizard().getConfigButton().setVisible(true);
                this.gettingJonasFieldFrame.getErrorLabel().setText("Error: " + "Invalid JOnAS Base folder");
            }
        }
    }

    /**
     * The action performed listener.
     * @param event the event to performed.
     */
    public void actionPerformed(final ActionEvent event) {
        if (event.getSource() == this.gettingJonasFieldFrame.getJbBrowseJonasRoot()) {
            browseJOnasRoot();
        } else if (event.getSource() == this.gettingJonasFieldFrame.getJbBrowseJonasBase()) {
            browseJOnasBase();
        } else if (event.getSource() == this.gettingJonasFieldFrame.getUseJonasBase()) {
            this.gettingJonasFieldFrame.showJonasBaseField(this.gettingJonasFieldFrame.getUseJonasBase().isSelected());
            if (this.gettingJonasFieldFrame.getUseJonasBase().isSelected()) {
                this.gettingJonasFieldFrame.getJonasBase().setText("");
                disabledConfigButtonAccordingToJonasBaseField();
            } else {
                this.gettingJonasFieldFrame.getErrorLabel().setText("");
            }
        }
    }

    /**
     * Browse JOnAS Root folder.
     */
    private void browseJOnasRoot() {
        JFileChooser fc = new JFileChooser();
        fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
        fc.setAcceptAllFileFilterUsed(false);
        if (fc.showOpenDialog(this.gettingJonasFieldFrame.getJonasRoot()) == JFileChooser.APPROVE_OPTION) {
            File file = fc.getSelectedFile();
            this.gettingJonasFieldFrame.getJonasRoot().setText(file.getAbsolutePath());
            setNextButtonAccordingToJonasRootField();
        }
    }

    /**
     * Browse JOnAS Base folder.
     */
    private void browseJOnasBase() {
        JFileChooser fc = new JFileChooser();
        fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
        fc.setAcceptAllFileFilterUsed(false);
        if (fc.showOpenDialog(this.gettingJonasFieldFrame.getJonasBase()) == JFileChooser.APPROVE_OPTION) {
            File file = fc.getSelectedFile();
            this.gettingJonasFieldFrame.getJonasBase().setText(file.getAbsolutePath());
            disabledConfigButtonAccordingToJonasBaseField();
        }
    }

    /**
     * Action to do when a key is typed.
     * @param ke the key typed.
     */
    public void keyTyped(final KeyEvent ke) {
    }

    /**
     * Action to do when a key is pressed.
     * @param ke the key pressed.
     */
    public void keyPressed(final KeyEvent ke) {
    }

    /**
     * Action to do when a key is released.
     * @param ke the key released.
     */
    public void keyReleased(final KeyEvent ke) {
        if (ke.getSource() == this.gettingJonasFieldFrame.getJonasRoot()) {
            setNextButtonAccordingToJonasRootField();
        } else if (ke.getSource() == this.gettingJonasFieldFrame.getJonasBase()) {
            disabledConfigButtonAccordingToJonasBaseField();
        }
    }
}
