/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasFieldFromWebsiteFrameDescriptor.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guibuilder;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import org.ow2.jonas.autostart.builder.Builder;
import org.ow2.jonas.autostart.configurationframe.ConfiguratorFrameDescriptor;
import org.ow2.jonas.autostart.frame.BuildSummaryFrame;
import org.ow2.jonas.autostart.frame.GettingJonasFieldFromWebsiteFrame;
import org.ow2.jonas.autostart.fullwizard.FullWizardPanelDescriptor;
import org.ow2.jonas.autostart.parser.Parser;
import org.ow2.jonas.autostart.parseurl.ParseUrl;

/**
 * This class intanciates GettingJonasFieldFromWebsiteFrame.
 * @author skabore
 */
public class GettingJonasFieldFromWebsiteFrameDescriptor extends FullWizardPanelDescriptor implements ActionListener {

    /**
     * The identifier.
     */
    public static final String IDENTIFIER = "GETTING_JONAS_FIELD_FROM_WEBSITE_PANEL";

    /**
     * the gettingJonasFieldFrame.
     */
    private GettingJonasFieldFromWebsiteFrame gettingJonasFieldFrame;

    /**
     * The builder librairy.
     */
    private Builder builder;

    /**
     * The constructeur.
     * @param builder the builder librairy
     * @param steps, the required steps to create a starter
     */
    public GettingJonasFieldFromWebsiteFrameDescriptor(final Builder builder, final int steps) {
        this.builder = builder;
        gettingJonasFieldFrame = new GettingJonasFieldFromWebsiteFrame(steps);
        gettingJonasFieldFrame.addActionListener(this);
        setPanelDescriptorIdentifier(IDENTIFIER);
        setPanelComponent(gettingJonasFieldFrame);
    }

    /**
     * @return builder.
     */
    public Builder getBuilder() {
        return builder;
    }

    /**
     * @return the next panel.
     */
    @Override
    public Object getNextPanelDescriptor() {
        setJonasUrl();
        setEnabledConfigButton();
        getWizard().setCurrentFrame(0);
        String[] applicationListItems = {};
        if (builder.getApplicationLocation() != null && builder.getApplicationLocation().length > 0) {
            applicationListItems = builder.getApplicationLocation();
        }
        BuildSummaryFrame.getApplicationList().setListData(applicationListItems);
        builder.setIncludeJonasClient(gettingJonasFieldFrame.getIncludeJonasClientCheckBox().isSelected());
        getWizard().setConfiguration(builder.getConfiguration());
        return BuildSummaryFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return the back panel.
     */
    @Override
    public Object getBackPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        return GettingJonasOptionFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return the config panel.
     */
    @Override
    public Object getConfigPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        getWizard().setCurrentFrame(0);
        return ConfiguratorFrameDescriptor.IDENTIFIER;
    }

    /**
     * Check if the next button must be enabled.
     */
    @Override
    public void aboutToDisplayPanel() {
        setNextButtonAccordingToJonasVersion();
    }

    /**
     * Set the next button enabled according fields values.
     */
    private void setNextButtonAccordingToJonasVersion() {
        String version = gettingJonasFieldFrame.getJonasVersionComboBox().getSelectedItem().toString();
        if (!version.equals("")) {
            gettingJonasFieldFrame.getErrorLabel().setText("");
            getWizard().setNextFinishButtonEnabled(true);
            setEnabledConfigButton();
        } else {
            gettingJonasFieldFrame.getErrorLabel().setText("Error:" + " No version selected.");
            getWizard().setNextFinishButtonEnabled(false);
            getWizard().getConfigButton().setVisible(false);
        }
    }

    /**
     * Enable the 'Set config' button.
     */
    private void setEnabledConfigButton() {
        boolean enabledConfigButton = getWizard().getNextFinishButtonEnabled()
                && gettingJonasFieldFrame.getSetJonasBaseCheckBox().isSelected();
        getWizard().getConfigButton().setVisible(enabledConfigButton);
        builder.setCreateNewJonasBase(enabledConfigButton);
    }

    /**
     * The action performed listener.
     * @param event the event to performed.
     */
    public void actionPerformed(final ActionEvent event) {
        if (event.getSource() == gettingJonasFieldFrame.getJonasVersionComboBox()) {
            setNextButtonAccordingToJonasVersion();
        } else if (event.getSource() == gettingJonasFieldFrame.getSetJonasBaseCheckBox()) {
            setEnabledConfigButton();
            boolean selected = gettingJonasFieldFrame.getSetJonasBaseCheckBox().isSelected();
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setSelected(selected);
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setEnabled(!selected);
        } else if (event.getSource() == gettingJonasFieldFrame.getMicroRadioButton()) {
            gettingJonasFieldFrame.getSetJonasBaseCheckBox().setSelected(false);
            gettingJonasFieldFrame.getSetJonasBaseCheckBox().setEnabled(false);
            setEnabledConfigButton();
            setJonasUrl();
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setSelected(false);
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setEnabled(false);
        } else if (event.getSource() == gettingJonasFieldFrame.getFullRadioButton()) {
            gettingJonasFieldFrame.getSetJonasBaseCheckBox().setSelected(true);
            gettingJonasFieldFrame.getSetJonasBaseCheckBox().setEnabled(true);
            setEnabledConfigButton();
            setJonasUrl();
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setSelected(true);
            getWizard().showMessage("To set the configuration, click " + "'Set config' button below !");
        } else if (event.getSource() == gettingJonasFieldFrame.getIncludeJonasClientCheckBox()) {
            builder.setIncludeJonasClient(gettingJonasFieldFrame.getIncludeJonasClientCheckBox().isSelected());
        }
    }

    /**
     * Create a URL for gettion JOnAS server based on choosen version and type.
     * @param type the type of JOnAS server to download.
     * @param version the version of JOnAS server to download.
     * @return JOnAS url.
     */
    private String createJOnASUrl(final String type, final String version) {
        Parser parser = new Parser("http://repo1.maven.org/maven2/org/ow2/" + "jonas/assemblies/maven-metadata.xml", "stable",
                "JOnAS");
        ParseUrl jonasZipFile = new ParseUrl(parser, "http://repo1.maven.org/maven2/org/ow2/jonas/" + "assemblies/profiles/",
                "-bin.zip", type);
        return jonasZipFile.getUrl(version);
    }

    /**
     * Set the JOnAS url according to selected version and type.
     */
    private void setJonasUrl() {
        String version = gettingJonasFieldFrame.getJonasVersionComboBox().getSelectedItem().toString();
        String type = "micro";
        if (gettingJonasFieldFrame.getFullRadioButton().isSelected()) {
            type = "full";
        }
        String url = createJOnASUrl(type, version);
        // try {
        // if (Utility.testConnexionURL(new URL(url))) {
        builder.setUrl(url);
        gettingJonasFieldFrame.getErrorLabel().setText("");
        /*
         * } else { gettingJonasFieldFrame.getErrorLabel().setText("Unable to" +
         * " establish Internet connection." +
         * " Check your connection settings !"); } catch (MalformedURLException
         * ex) { java.util.logging.Logger.getLogger(
         * GettingJonasFieldFromWebsiteFrameDescriptor.class.getName(
         * )).log(Level.SEVERE, null, ex); }}
         */
    }
}
