/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasFieldFromZipFileFrameDescriptor.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guibuilder;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.swing.JFileChooser;

import org.ow2.jonas.autostart.builder.Builder;
import org.ow2.jonas.autostart.configurationframe.ConfiguratorFrameDescriptor;
import org.ow2.jonas.autostart.frame.BuildSummaryFrame;
import org.ow2.jonas.autostart.frame.GettingJonasFieldFromZipFileFrame;
import org.ow2.jonas.autostart.fullwizard.FullWizardPanelDescriptor;
import org.ow2.jonas.autostart.utility.CustomFileFilter;
import org.ow2.jonas.autostart.utility.Utility;

/**
 * This class instanciates gettingJonasFieldFromZipFileFrame. frame.
 * @author skabore
 */
public class GettingJonasFieldFromZipFileFrameDescriptor extends FullWizardPanelDescriptor implements ActionListener,
        KeyListener {

    /**
     * The identifier.
     */
    public static final String IDENTIFIER = "GETTING_JONAS_FIELD_FROM_ZIP_FILE_PANEL";

    /**
     * the gettingJonasFieldFromZipFileFrame.
     */
    private GettingJonasFieldFromZipFileFrame gettingJonasFieldFrame;

    /**
     * The builder librairy.
     */
    private Builder builder;

    /**
     * The constructeur.
     * @param builder the builder librairy
     * @param steps, the required steps to create a starter
     */
    public GettingJonasFieldFromZipFileFrameDescriptor(final Builder builder, final int steps) {
        this.builder = builder;
        gettingJonasFieldFrame = new GettingJonasFieldFromZipFileFrame(steps);
        gettingJonasFieldFrame.addActionListener(this);
        gettingJonasFieldFrame.addKeyListener(this);
        setPanelDescriptorIdentifier(IDENTIFIER);
        setPanelComponent(gettingJonasFieldFrame);
    }

    /**
     * @return builder.
     */
    public Builder getBuilder() {
        return builder;
    }

    /**
     * @return the next panel identifier.
     */
    @Override
    public Object getNextPanelDescriptor() {
        // getWizard().getConfigButton().setVisible(true);
        getWizard().setCurrentFrame(2);
        String[] applicationListItems = {};
        if (builder.getApplicationLocation() != null && builder.getApplicationLocation().length > 0) {
            applicationListItems = builder.getApplicationLocation();
        }
        BuildSummaryFrame.getApplicationList().setListData(applicationListItems);
        builder.setIncludeJonasClient(gettingJonasFieldFrame.getIncludeJonasClientCheckBox().isSelected());
        getWizard().setConfiguration(builder.getConfiguration());
        return BuildSummaryFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return the back panel identifier.
     */
    @Override
    public Object getBackPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        return GettingJonasOptionFrameDescriptor.IDENTIFIER;
    }

    /**
     * @return the config panel identifier.
     */
    @Override
    public Object getConfigPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        getWizard().setCurrentFrame(2);
        return ConfiguratorFrameDescriptor.IDENTIFIER;
    }

    /**
     * Check if the next button must be enabled.
     */
    @Override
    public void aboutToDisplayPanel() {
        setNextButtonAccordingToJonasZipFileField();
    }

    /**
     * Set the next button enabled according to JOnAS zip file fields.
     */
    private void setNextButtonAccordingToJonasZipFileField() {
        if (gettingJonasFieldFrame.getCopyRadioButton().isSelected()) {
            if (gettingJonasFieldFrame.getZipFilePath().getText().equals("")) {
                getWizard().setNextFinishButtonEnabled(false);
                getWizard().getConfigButton().setVisible(false);
                gettingJonasFieldFrame.getErrorLabel().setText("");
            } else {
                String zipFile = gettingJonasFieldFrame.getZipFilePath().getText();
                if (new File(zipFile).exists() && zipFile.endsWith(".zip")) {
                    builder.setUrl(gettingJonasFieldFrame.getZipFilePath().getText());
                    getWizard().setNextFinishButtonEnabled(true);
                    gettingJonasFieldFrame.getErrorLabel().setText("");
                } else {
                    getWizard().setNextFinishButtonEnabled(false);
                    gettingJonasFieldFrame.getErrorLabel().setText("JOnAS zip" + " file is not valid !");
                }
                /*
                 * builder.setCreateNewJonasBase(
                 * gettingJonasFieldFrame.getSetJonasBaseCheckBox(
                 * ).isSelected());
                 */
                setEnabledConfigButton();
            }
        } else if (gettingJonasFieldFrame.getDownloadRadioButton().isSelected()) {
            if (gettingJonasFieldFrame.getZipFileUrl().getText().equals("")) {
                gettingJonasFieldFrame.getErrorLabel().setText("");
                getWizard().setNextFinishButtonEnabled(false);
                getWizard().getConfigButton().setVisible(false);
            } else {
                String zipFile = gettingJonasFieldFrame.getZipFileUrl().getText();
                try {
                    if (Utility.testConnexionURL(new URL(zipFile)) && zipFile.endsWith(".zip")) {
                        builder.setUrl(gettingJonasFieldFrame.getZipFileUrl().getText());
                        getWizard().setNextFinishButtonEnabled(true);
                        gettingJonasFieldFrame.getErrorLabel().setText("");
                    } else {
                        getWizard().setNextFinishButtonEnabled(false);
                        gettingJonasFieldFrame.getErrorLabel().setText("JOnAS" + " zip" + " file is not valid !");
                    }
                } catch (MalformedURLException ex) {
                    Logger.getLogger(GettingJonasFieldFromZipFileFrameDescriptor.class.getName()).log(Level.SEVERE, null, ex);
                }
                setEnabledConfigButton();
            }
        }
    }

    /**
     * Enable the 'Set config' button.
     */
    private void setEnabledConfigButton() {
        boolean enabledConfigButton = getWizard().getNextFinishButtonEnabled()
                && gettingJonasFieldFrame.getSetJonasBaseCheckBox().isSelected();
        getWizard().getConfigButton().setVisible(enabledConfigButton);
        builder.setCreateNewJonasBase(enabledConfigButton);
    }

    /**
     * The action performed listener.
     * @param event the event to performed.
     */
    public void actionPerformed(final ActionEvent event) {
        if (event.getSource() == gettingJonasFieldFrame.getCopyRadioButton()) {
            gettingJonasFieldFrame.enabledZipFileField();
        } else if (event.getSource() == gettingJonasFieldFrame.getDownloadRadioButton()) {
            gettingJonasFieldFrame.enabledZipFileField();
        } else if (event.getSource() == gettingJonasFieldFrame.getJbBrowseZipFile()) {
            browseZipFile();
        } else if (event.getSource() == gettingJonasFieldFrame.getSetJonasBaseCheckBox()) {
            setEnabledConfigButton();
            boolean selected = gettingJonasFieldFrame.getSetJonasBaseCheckBox().isSelected();
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setSelected(selected);
            gettingJonasFieldFrame.getIncludeJonasClientCheckBox().setEnabled(!selected);
            if (gettingJonasFieldFrame.getSetJonasBaseCheckBox().isSelected()) {
                getWizard().showMessage(
                        "To set the configuration, click " + "'Set config' button below !\n"
                                + "Be sure the zip file contains a valid full" + " JOnAS server (Folder ../templates/conf is"
                                + " required).");
            }
        } else if (event.getSource() == gettingJonasFieldFrame.getIncludeJonasClientCheckBox()) {
            builder.setIncludeJonasClient(gettingJonasFieldFrame.getIncludeJonasClientCheckBox().isSelected());
        }
    }

    /**
     * Action to do when a key is typed.
     * @param ke the key typed.
     */
    public void keyTyped(final KeyEvent ke) {
    }

    /**
     * Action to do when a key is pressed.
     * @param ke the key pressed.
     */
    public void keyPressed(final KeyEvent ke) {
    }

    /**
     * Action to do when a key is released.
     * @param ke the key released.
     */
    public void keyReleased(final KeyEvent ke) {
        if (ke.getSource() == gettingJonasFieldFrame.getZipFilePath()) {
            setNextButtonAccordingToJonasZipFileField();
        } else if (ke.getSource() == gettingJonasFieldFrame.getZipFileUrl()) {
            setNextButtonAccordingToJonasZipFileField();
        }
    }

    /**
     * Browse zip file.
     */
    private void browseZipFile() {
        CustomFileFilter fileFilter = new CustomFileFilter(new String[] {"zip"}, "JOnAS server zip file (.zip)");
        JFileChooser fc = new JFileChooser();
        fc.setFileFilter(fileFilter);
        fc.setAcceptAllFileFilterUsed(false);
        fc.setDragEnabled(true);
        if (fc.showOpenDialog(gettingJonasFieldFrame.getZipFilePath()) == JFileChooser.APPROVE_OPTION) {
            File file = fc.getSelectedFile();
            gettingJonasFieldFrame.getZipFilePath().setText(file.getAbsolutePath());
            setNextButtonAccordingToJonasZipFileField();
        }
    }
}
