/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasOptionFrameDescriptor.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.guibuilder;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import org.ow2.jonas.autostart.frame.GettingJonasOptionFrame;
import org.ow2.jonas.autostart.fullwizard.FullWizardPanelDescriptor;

/**
 * This class instantiates GettingJonasOptionFrame.
 * @author skabore
 */
public class GettingJonasOptionFrameDescriptor extends FullWizardPanelDescriptor implements ActionListener {

    /**
     * The identifier.
     */
    public static final String IDENTIFIER = "GETTING_JONAS_OPTION_PANEL";

    /**
     * The gettingJonasOption frame.
     */
    private GettingJonasOptionFrame gettingJonasOptionFrame;

    /**
     * The constructeur.
     * @param builder the builder librairy
     * @param steps, the required steps to create a starter
     */
    public GettingJonasOptionFrameDescriptor(final int steps) {
        gettingJonasOptionFrame = new GettingJonasOptionFrame(steps);
        gettingJonasOptionFrame.addActionListener(this);
        setPanelDescriptorIdentifier(IDENTIFIER);
        setPanelComponent(gettingJonasOptionFrame);
    }

    /**
     * @return the next panel.
     */
    @Override
    public Object getNextPanelDescriptor() {
        if (gettingJonasOptionFrame.getFromDiskRadioButton().isSelected()) {
            return GettingJonasFieldFromDiskFrameDescriptor.IDENTIFIER;
        } else if (gettingJonasOptionFrame.getFromWebsiteRadioButton().isSelected()) {
            return GettingJonasFieldFromWebsiteFrameDescriptor.IDENTIFIER;
        } else if (gettingJonasOptionFrame.getFromExistingZipFileRadioButton().isSelected()) {
            return GettingJonasFieldFromZipFileFrameDescriptor.IDENTIFIER;
        }
        return null;
    }

    /**
     * @return the back panel.
     */
    @Override
    public Object getBackPanelDescriptor() {
        getWizard().getConfigButton().setVisible(false);
        return ApplicationFrameDescriptor.IDENTIFIER;
    }

    /**
     * Check if the next button must be enabled.
     */
    @Override
    public void aboutToDisplayPanel() {
    }

    /**
     * The action performed listener.
     * @param event the event to performed.
     */
    public void actionPerformed(final ActionEvent event) {
    }
}
